@@ -30,6 +30,7 @@ from typing import (
     Generic,
     Iterable,
     Mapping,
+    Optional,
     Set,
     Tuple,
     Type,
@@ -212,7 +213,7 @@ class ConfigBase(BaseModel, Generic[Secrets]):
                                 else:
                                     raise ValueError(
                                         "'value' attribute not included "
-                                        f"for remote field '{remote_attr_name}'"
+                                        f"for remote field '{remote_attr_name}' "
                                         "and 'field_default' not defined in local attribute",
                                     ) from None
                             break
@@ -512,6 +513,10 @@ class ConfigBase(BaseModel, Generic[Secrets]):
 
         Supported `RemoteMapEntry` optional parameters:
 
+        * `equals` (`Callable[[Any, Any], bool], default: (use `a == b`))
+            * Callable function for comparing the local and remote values,
+              and return if they are equal or not, with `True` being returned
+              if they are equal, and `False` if not
         * `encoder` (`Callable[[Any], Any]`, default: (use internal function))
             * Callable function for parsing the local value to its remote equivalent
         * `root_encoder` (`Callable[[Self], Any]`, default: (undefined))
@@ -550,6 +555,9 @@ class ConfigBase(BaseModel, Generic[Secrets]):
             set_value = False
 
             #
+            def equals(a: Any, b: Any) -> bool:
+                return a == b
+
             def formatter(v: Any) -> str:
                 return repr(attr_metadata.get("formatter", self._format_attr)(v))
 
@@ -565,7 +573,7 @@ class ConfigBase(BaseModel, Generic[Secrets]):
                 local_value = getattr(self, attr_name)
                 # If the local and remote attributes are set to the same
                 # value, unless set_unchanged is set to True, do nothing.
-                if local_value == remote_value:
+                if attr_metadata.get("equals", equals)(local_value, remote_value):
                     if attr_name not in already_logged:
                         logger.debug(
                             "%s.%s: %s (up to date)",
@@ -712,17 +720,30 @@ class ConfigBase(BaseModel, Generic[Secrets]):
             return [cls._encode_attr(v) for v in value]
         return value
 
-    def yaml(self, *args, **kwargs) -> str:
+    def yaml(
+        self,
+        *args,
+        sort_keys: bool = False,
+        yaml_kwargs: Optional[Mapping[str, Any]] = None,
+        **kwargs,
+    ) -> str:
         """
         Generate a YAML representation of the model.
 
         Internally this uses the Pydantic JSON generation function, with all arguments
         forwarded to `BaseModel.json()`. The JSON output is then re-processed using PyYAML.
 
+        Args:
+            sort_keys (bool, optional): Sort keys in the output YAML file. Defaults to `False`.
+            yaml_kwargs (Optional[Mapping[str, Any]], optional): YAML encoder keyword args.
+
         Returns:
             YAML representation of the model
         """
-        return yaml.safe_dump(json.loads(self.json(*args, **kwargs)))
+        return yaml.safe_dump(  # type: ignore[call-overload]
+            json.loads(self.json(*args, **kwargs)),
+            **{**(yaml_kwargs or {}), "sort_keys": sort_keys},
+        )
 
     class Config:
         """
