@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -19,6 +17,8 @@ Dummy plugin type hints.
 """
 
 
+from __future__ import annotations
+
 from typing import Literal
 
 from buildarr.types import Password
