@@ -20,7 +20,7 @@ Buildarr secrets metadata interface.
 from __future__ import annotations
 
 from .base import SecretsBase
-from .load import load
+from .load import load_secrets
 from .models import SecretsPlugin, SecretsType
 
-__all__ = ["SecretsBase", "SecretsPlugin", "SecretsType", "load"]
+__all__ = ["SecretsBase", "SecretsPlugin", "SecretsType", "load_secrets"]
